Index: /CKEditor/branches/features/adobeair/_source/core/dom/element.js
===================================================================
--- /CKEditor/branches/features/adobeair/_source/core/dom/element.js	(revision 6160)
+++ /CKEditor/branches/features/adobeair/_source/core/dom/element.js	(revision 6161)
@@ -308,18 +308,31 @@
 		/**
 		 * Moves the selection focus to this element.
+		 * @param  {Boolean} Whether defer the focusing into new thread after a little while.
 		 * @example
 		 * var element = CKEDITOR.document.getById( 'myTextarea' );
 		 * <b>element.focus()</b>;
 		 */
-		focus : function()
-		{
-			// IE throws error if the element is not visible.
-			try
-			{
-				this.$.focus();
-			}
-			catch (e)
-			{}
-		},
+		focus : (function()
+		{
+			function exec( element )
+			{
+				// IE throws error if the element is not visible.
+				try
+				{
+					element.$.focus();
+				}
+				catch (e)
+				{}
+			}
+
+			return function( defer )
+			{
+				var self = this;
+				if ( defer )
+					setTimeout( function(){ exec( self ) }, 100 );
+				else
+					exec( this );
+			}
+		}()),
 
 		/**
Index: /CKEditor/branches/features/adobeair/_source/plugins/elementspath/plugin.js
===================================================================
--- /CKEditor/branches/features/adobeair/_source/plugins/elementspath/plugin.js	(revision 6160)
+++ /CKEditor/branches/features/adobeair/_source/plugins/elementspath/plugin.js	(revision 6161)
@@ -20,6 +20,7 @@
 				var element = CKEDITOR.document.getById( idBase + '0' );
 
-				if ( element )
-					element.focus();
+				// Make the first button focus accessible for IE. (#3417)
+				// Adobe AIR instead need while of delay.
+				element && element.focus( CKEDITOR.env.ie || CKEDITOR.env.air );
 			}
 		}
Index: /CKEditor/branches/features/adobeair/_source/plugins/toolbar/plugin.js
===================================================================
--- /CKEditor/branches/features/adobeair/_source/plugins/toolbar/plugin.js	(revision 6160)
+++ /CKEditor/branches/features/adobeair/_source/plugins/toolbar/plugin.js	(revision 6161)
@@ -44,6 +44,7 @@
 					editor.toolbox.focusCommandExecuted = true;
 
-					// Make the first button focus accessible. (#3417)
-					if ( CKEDITOR.env.ie )
+					// Make the first button focus accessible for IE. (#3417)
+					// Adobe AIR instead need while of delay.
+					if ( CKEDITOR.env.ie || CKEDITOR.env.air )
 						setTimeout( function(){ editor.toolbox.focus(); }, 100 );
 					else
